@@ -274,6 +274,21 @@ def padding_cropped_img(cropped_img_file, orig_img_file, indiv_crop):
     return padded_img_file
 
 
+def reg_aladin_dirty(reference, in_file):
+
+    import os
+
+    cwd = os.path.abspath("")
+    os.chdir(cwd)
+    out_file = os.path.abspath("outputResult.nii")
+    cmd = "reg_aladin -flo {} -ref {} -res {}".format(
+        in_file, reference, out_file)
+    os.system(cmd)
+
+    assert os.path.exists(out_file)
+    return out_file
+
+
 if __name__ == '__main__':
 
     data_path = "/hpc/meca/data/Macaques/Macaque_hiphop/results/ucdavis"
